import json
import os
import logging

TEMPLATES = {}
logger = logging.getLogger("template")

def check_local_template(local_name):
    template_def = TEMPLATES[local_name]
    base_dir = template_def.get("local_path")
    for video_part in template_def.get("video_parts", []):
        source_file = video_part.get("source", "")
        if str(source_file).startswith("http"):
            # download file
            ...
        elif str(source_file).startswith("PLACEHOLDER_"):
            continue
        else:
            if not os.path.isabs(source_file):
                source_file = os.path.join(base_dir, source_file)
            if not os.path.exists(source_file):
                logger.error(f"{source_file} not found, please check the template definition")
                raise Exception(f"{source_file} not found, please check the template definition")
        for audio in video_part.get("audios", []):
            if not os.path.isabs(audio):
                audio = os.path.join(base_dir, audio)
            if not os.path.exists(audio):
                logger.error(f"{audio} not found, please check the template definition")
                raise Exception(f"{audio} not found, please check the template definition")
        for lut in video_part.get("luts", []):
            if not os.path.isabs(lut):
                lut = os.path.join(base_dir, lut)
            if not os.path.exists(lut):
                logger.error(f"{lut} not found, please check the template definition")
                raise Exception(f"{lut} not found, please check the template definition")
        for mask in video_part.get("overlays", []):
            if not os.path.isabs(mask):
                mask = os.path.join(base_dir, mask)
            if not os.path.exists(mask):
                logger.error(f"{mask} not found, please check the template definition")
                raise Exception(f"{mask} not found, please check the template definition")


def load_template(template_name, local_path):
    global TEMPLATES
    logger.info(f"加载视频模板定义：【{template_name}（{local_path}）】")
    template_def_file = os.path.join(local_path, "template.json")
    if os.path.exists(template_def_file):
        TEMPLATES[template_name] = json.load(open(template_def_file, 'rb'))
        TEMPLATES[template_name]["local_path"] = local_path
        try:
            check_local_template(template_name)
            logger.info(f"完成加载【{template_name}】模板")
        except Exception as e:
            logger.error(f"模板定义文件【{template_def_file}】有误，正在尝试重新下载模板", exc_info=e)
            download_template(template_name)


def load_local_template():
    for template_name in os.listdir(os.getenv("TEMPLATE_DIR")):
        if template_name.startswith("_"):
            continue
        if template_name.startswith("."):
            continue
        target_path = os.path.join(os.getenv("TEMPLATE_DIR"), template_name)
        if os.path.isdir(target_path):
            load_template(template_name, target_path)


def get_template_def(template_id):
    return TEMPLATES.get(template_id)

def download_template(template_id):
    logger.info(f"下载模板：{template_id}")
    ...


def analyze_template(template_id):
    ...
